summary refs log tree commit diff
path: root/nixos/modules/system/boot/stage-1.nix
diff options
context:
space:
mode:
authorGraham Christensen <graham@grahamc.com>2020-11-24 10:29:28 -0500
committerGraham Christensen <graham@grahamc.com>2020-11-24 12:42:06 -0500
commitbc49a0815ae860010b4d593b02f00ab6f07d50ea (patch)
tree1435af86f0f2172632621a400f27a44599751f17 /nixos/modules/system/boot/stage-1.nix
parent79086e5d55e037b994c839c2894a3667ae72547b (diff)
downloadnixpkgs-bc49a0815ae860010b4d593b02f00ab6f07d50ea.tar
nixpkgs-bc49a0815ae860010b4d593b02f00ab6f07d50ea.tar.gz
nixpkgs-bc49a0815ae860010b4d593b02f00ab6f07d50ea.tar.bz2
nixpkgs-bc49a0815ae860010b4d593b02f00ab6f07d50ea.tar.lz
nixpkgs-bc49a0815ae860010b4d593b02f00ab6f07d50ea.tar.xz
nixpkgs-bc49a0815ae860010b4d593b02f00ab6f07d50ea.tar.zst
nixpkgs-bc49a0815ae860010b4d593b02f00ab6f07d50ea.zip
utillinux: rename to util-linux
Diffstat (limited to 'nixos/modules/system/boot/stage-1.nix')
-rw-r--r--nixos/modules/system/boot/stage-1.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/nixos/modules/system/boot/stage-1.nix b/nixos/modules/system/boot/stage-1.nix
index 6823e12847c..0f5787a1921 100644
--- a/nixos/modules/system/boot/stage-1.nix
+++ b/nixos/modules/system/boot/stage-1.nix
@@ -107,8 +107,8 @@ let
         copy_bin_and_libs $BIN
       done
 
-      # Copy some utillinux stuff.
-      copy_bin_and_libs ${pkgs.utillinux}/sbin/blkid
+      # Copy some util-linux stuff.
+      copy_bin_and_libs ${pkgs.util-linux}/sbin/blkid
 
       # Copy dmsetup and lvm.
       copy_bin_and_libs ${getBin pkgs.lvm2}/bin/dmsetup
@@ -235,7 +235,7 @@ let
             --replace scsi_id ${extraUtils}/bin/scsi_id \
             --replace cdrom_id ${extraUtils}/bin/cdrom_id \
             --replace ${pkgs.coreutils}/bin/basename ${extraUtils}/bin/basename \
-            --replace ${pkgs.utillinux}/bin/blkid ${extraUtils}/bin/blkid \
+            --replace ${pkgs.util-linux}/bin/blkid ${extraUtils}/bin/blkid \
             --replace ${getBin pkgs.lvm2}/bin ${extraUtils}/bin \
             --replace ${pkgs.mdadm}/sbin ${extraUtils}/sbin \
             --replace ${pkgs.bash}/bin/sh ${extraUtils}/bin/sh \